dot-hbayesdm_extract: Extract draws for the requested parameters from a cmdstanr...

.hbayesdm_extractR Documentation

Extract draws for the requested parameters from a cmdstanr fit.

Description

Returns a named list. Each element has draws on axis 1 followed by the parameter's own dimensions.

Usage

.hbayesdm_extract(fit, pars)

hBayesDM documentation built on Sept. 10, 2026, 1:12 a.m.