General Purpose Plotting for hBayesDM. This function plots hyper parameters.

# S3 method for class 'hBayesDM'
plot(
  x = NULL,
  type = "dist",
  ncols = NULL,
  font_size = NULL,
  bin_size = NULL,
  ...
)

Arguments

x

Model output of class hBayesDM

type

Character value that specifies the plot type. Options are: "dist", "trace", or "simple". Defaults to "dist".

ncols

Integer value specifying how many plots there should be per row. Defaults to the number of parameters.

font_size

Integer value specifying the size of the font used for plotting. Defaults to 10.

bin_size

Integer value specifying how wide the bars on the histogram should be. Defaults to 30.

...

Additional arguments to be passed on