Learn R Programming

hBayesDM (version 0.2.3.3)

hBayesDM-package: Hierarchical Bayesian Modeling of Decision-Making Tasks

Description

Fit an array of decision-making tasks with computational models in a hierarchical Bayesian framework. Can perform hierarchical Bayesian analysis of various computational models with a single line of coding.

Arguments

Details

Bolded tasks, followed by their respective models, are itemized below.

References

Please cite as: Ahn, W.-Y., Haines, N., & Zhang, L. (2016). Revealing neuro-computational mechanisms of reinforcement learning and decision-making with the hBayesDM package. bioRxiv. http://doi.org/10.1101/064287

See Also

For tutorials and further readings, visit : http://rpubs.com/CCSL/hBayesDM.