| hdi | R Documentation |
Computes the highest density interval from a sample of representative values, estimated as shortest credible interval. Based on John Kruschke's codes.
hdi(sample_vec, ci_prob = 0.95)
sample_vec |
A vector of representative values from a probability distribution (e.g., MCMC samples). |
ci_prob |
A scalar between 0 and 1, indicating the mass within the credible interval that is to be estimated. |
A vector containing the limits of the HDI
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.